package org.dromara.rfid.mapper;

import org.dromara.rfid.domain.RfidDevice;
import org.dromara.rfid.domain.vo.RfidDeviceVo;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import org.apache.ibatis.annotations.Param;
import java.util.List;
import java.util.Collection;

/**
 * 设备信息Mapper接口
 *
 * @author zch
 * @date 2025-11-25
 */
public interface RfidDeviceMapper extends BaseMapperPlus<RfidDevice, RfidDeviceVo> {

    /**
     * 查询设备信息列表（自定义条件）
     *
     * @param queryWrapper 条件
     * @return 设备信息集合
     */
    List<RfidDeviceVo> selectCustomRfidDeviceVoList(@Param(Constants.WRAPPER) Wrapper<RfidDevice> queryWrapper);

    /**
     * 根据ID查询设备信息详情
     *
     * @param id 主键ID
     * @return 设备信息对象
     */
    RfidDeviceVo selectCustomRfidDeviceVoById(@Param("id") Long id);

    /**
     * 根据ID列表批量查询设备信息
     *
     * @param ids ID集合
     * @return 设备信息集合
     */
    List<RfidDeviceVo> selectCustomRfidDeviceVoByIds(@Param("ids") Collection<Long> ids);

    /**
     * 统计设备信息记录数
     *
     * @param queryWrapper 查询条件
     * @return 记录总数
     */
    Long countCustomRfidDevice(@Param(Constants.WRAPPER) Wrapper<RfidDevice> queryWrapper);

    /**
     * 分页查询设备信息（自定义条件）
     *
     * @param page         分页对象
     * @param queryWrapper 查询条件
     * @return 分页结果
     */
    Page<RfidDeviceVo> selectCustomRfidDeviceVoPage(@Param("page") Page<RfidDevice> page, @Param(Constants.WRAPPER) Wrapper<RfidDevice> queryWrapper);

    /**
     * 批量插入设备信息
     *
     * @param list 设备信息对象集合
     * @return 影响行数
     */
    int batchInsertRfidDevice(@Param("list") List<RfidDevice> list);

    /**
     * 批量更新设备信息
     *
     * @param list 设备信息对象集合
     * @return 影响行数
     */
    int batchUpdateRfidDevice(@Param("list") List<RfidDevice> list);

    /**
     * 根据自定义条件删除设备信息
     *
     * @param queryWrapper 删除条件
     * @return 影响行数
     */
    int deleteCustomRfidDevice(@Param(Constants.WRAPPER) Wrapper<RfidDevice> queryWrapper);

    /**
     * 根据ID列表批量删除设备信息
     *
     * @param ids ID集合
     * @return 影响行数
     */
    int deleteCustomRfidDeviceByIds(@Param("ids") Collection<Long> ids);

    /**
     * 检查设备信息是否存在
     *
     * @param queryWrapper 查询条件
     * @return 是否存在
     */
    Boolean existsRfidDevice(@Param(Constants.WRAPPER) Wrapper<RfidDevice> queryWrapper);


}
